Skip to contents

Translates formula_list objects into a Formula::Formula

Usage

fmllst2Fml(fmllst, drop_lhs = NULL)

Arguments

fmllst

A formula_list classed object.

drop_lhs

An integer vector.

Used as a selection vector to remove response names prior to generating the Formula object. This vector must be composed of integers (e.g., 1L and not 1).

This is useful for some Formulas that do not have a separate responses for each left hand side model part (e.g., pscl::zeroinfl) but are required to have separate responses by formula_list.

Value

A Formula::Formula object.