Defines a list object class composed of formula objects that
is used to obtain RHS-LHS pairs in its domir S3 method.
Usage
formula_list(...)
Value
A list of class formula_list.
Arguments
...
formulas, possibly named
Details
All formula_lists enforce requirements that the list are composed of
individual formulas and that each formula is unique with its own,
different, non-NULL dependent variable/response.