Reports dominance designation results from the domin class object.
Usage
# S3 method for class 'domin'
summary(object, ...)Value
The originally submitted "domin" object with an additional Strongest_Dominance element added.
Strongest_DominanceMatrix comparing the independent variable in the first row to the independent variable in the third row. The second row denotes the strongest designation between the two independent variables.