Translates formula_list objects into a Formula::Formula
Arguments
- fmllst
A
formula_listclassed object.- drop_lhs
An integer vector.
Used as a selection vector to remove response names prior to generating the
Formulaobject. This vector must be composed of integers (e.g., 1L and not 1).This is useful for some
Formulasthat do not have a separate responses for each left hand side model part (e.g.,pscl::zeroinfl) but are required to have separate responses byformula_list.
Value
A Formula::Formula object.