formula_list into Formula::FormulaTranslates formula_list objects into a Formula::Formula
fmllst2Fml(fmllst, drop_lhs = NULL)A Formula::Formula object.
A formula_list classed object.
An integer vector.
Used as a selection vector to remove left hand side names prior to
generating the Formula object. This vector must be composed of
integers (e.g., 1L and not 1).
This is useful for some Formulas that do not have a separate
LHS for each LHS model part (e.g., pscl::zeroinfl) but are required
to have separte LHS parts by formula_list.